Currently everyone and their dog has their own favourite spelling
for vga_switcheroo. This makes it hard to grep dmesg for log entries
relating to vga_switcheroo. It also makes it hard to find related
source files in the tree.

vga_switcheroo.c uses pr_fmt "vga_switcheroo". Use that everywhere.

Signed-off-by: Lukas Wunner <lukas at wunner.de>
Reviewed-by: Takashi Iwai <tiwai at suse.de>
---
 sound/pci/hda/hda_controller.h |  2 +-
 sound/pci/hda/hda_intel.c      | 12 ++++++------
 sound/pci/hda/hda_intel.h      |  2 +-
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/sound/pci/hda/hda_controller.h b/sound/pci/hda/hda_controller.h
index 314105c..7b635d6 100644
--- a/sound/pci/hda/hda_controller.h
+++ b/sound/pci/hda/hda_controller.h
@@ -153,7 +153,7 @@ struct azx {
        unsigned int snoop:1;
        unsigned int align_buffer_size:1;
        unsigned int region_requested:1;
-       unsigned int disabled:1; /* disabled by VGA-switcher */
+       unsigned int disabled:1; /* disabled by vga_switcheroo */

 #ifdef CONFIG_SND_HDA_DSP_LOADER
        struct azx_dev saved_azx_dev;
diff --git a/sound/pci/hda/hda_intel.h b/sound/pci/hda/hda_intel.h
index 354f0bb..ff0c4d6 100644
--- a/sound/pci/hda/hda_intel.h
+++ b/sound/pci/hda/hda_intel.h
@@ -35,7 +35,7 @@ struct hda_intel {
        unsigned int irq_pending_warned:1;
        unsigned int probe_continued:1;

-       /* VGA-switcheroo setup */
+       /* vga_switcheroo setup */
        unsigned int use_vga_switcheroo:1;
        unsigned int vga_switcheroo_registered:1;
        unsigned int init_failed:1; /* delayed init failed */
diff --git a/sound/pci/hda/hda_intel.c b/sound/pci/hda/hda_intel.c
index e819013..45233731 100644
--- a/sound/pci/hda/hda_intel.c
+++ b/sound/pci/hda/hda_intel.c
@@ -337,7 +337,7 @@ enum {
         AZX_DCAPS_4K_BDLE_BOUNDARY | AZX_DCAPS_SNOOP_OFF)

 /*
- * VGA-switcher support
+ * vga_switcheroo support
  */
 #ifdef SUPPORT_VGA_SWITCHEROO
 #define use_vga_switcheroo(chip)       ((chip)->use_vga_switcheroo)
@@ -1076,12 +1076,12 @@ static void azx_vs_set_state(struct pci_dev *pci,
                        }
                }
        } else {
-               dev_info(chip->card->dev, "%s via VGA-switcheroo\n",
+               dev_info(chip->card->dev, "%s via vga_switcheroo\n",
                         disabled ? "Disabling" : "Enabling");
                if (disabled) {
                        pm_runtime_put_sync_suspend(card->dev);
                        azx_suspend(card->dev);
-                       /* when we get suspended by vga switcheroo we end up in 
D3cold,
+                       /* when we get suspended by vga_switcheroo we end up in 
D3cold,
                         * however we have no ACPI handle, so pci/acpi can't 
put us there,
                         * put ourselves there */
                        pci->current_state = PCI_D3cold;
@@ -1121,7 +1121,7 @@ static void init_vga_switcheroo(struct azx *chip)
        struct pci_dev *p = get_bound_vga(chip->pci);
        if (p) {
                dev_info(chip->card->dev,
-                        "Handle VGA-switcheroo audio client\n");
+                        "Handle vga_switcheroo audio client\n");
                hda->use_vga_switcheroo = 1;
                pci_dev_put(p);
        }
@@ -1232,7 +1232,7 @@ static int azx_dev_free(struct snd_device *device)

 #ifdef SUPPORT_VGA_SWITCHEROO
 /*
  * Check of disabled HDMI controller by vga-switcheroo
  */
 static struct pci_dev *get_bound_vga(struct pci_dev *pci)
 {
@@ -1917,7 +1917,7 @@ static int azx_probe(struct pci_dev *pci,

        err = register_vga_switcheroo(chip);
        if (err < 0) {
-               dev_err(card->dev, "Error registering VGA-switcheroo client\n");
+               dev_err(card->dev, "Error registering vga_switcheroo client\n");
                goto out_free;
        }
@@ -1232,7 +1232,7 @@ static int azx_dev_free(struct snd_device *device)
 #ifdef SUPPORT_VGA_SWITCHEROO
 /*
- * Check of disabled HDMI controller by vga-switcheroo
+ * Check of disabled HDMI controller by vga_switcheroo
  */
 static struct pci_dev *get_bound_vga(struct pci_dev *pci)

-- 
1.8.5.2 (Apple Git-48)

Reply via email to